// Package helpers provides helpers functions
package helpers

import (
	"crypto/hmac"
	"crypto/sha256"
	"encoding/hex"
	"encoding/json"
	"strconv"

	account "gitlab.mashroom.com/mashroom/backend/account/api"
	"gitlab.mashroom.com/mashroom/backend/account/internal/model"
)

// ComputeHmac256 making a hash of secret
func ComputeHmac256(message string, secret string) string {
	key := []byte(secret)
	h := hmac.New(sha256.New, key)
	h.Write([]byte(message))
	hash := hex.EncodeToString(h.Sum(nil))

	return hash
}

// ComputeHmac256Bytes making a hash of secret
func ComputeHmac256Bytes(message []byte, secret string) string {
	key := []byte(secret)
	h := hmac.New(sha256.New, key)
	h.Write(message)
	hash := hex.EncodeToString(h.Sum(nil))

	return hash
}

// DeleteResponseHelper unmarshal data based on response format
func DeleteResponseHelper(data []byte) (*account.DeleteSessionResponse, error) {
	base := &model.DeleteBaseResponse{}
	if err := json.Unmarshal(data, &base); err != nil {
		return nil, err
	}

	switch v := base.Status.(type) {
	case string:
		switch v {
		case "success":
			success := &model.DeleteSucceedResponse{}
			if err := json.Unmarshal(base.Data, &success); err != nil {
				return nil, err
			}

			return &account.DeleteSessionResponse{
				Status: v,
				Id:     success.Verification.ID}, nil
		case "fail":
			failed := &model.DeleteFailedResponse{}
			if err := json.Unmarshal(base.Data, &failed); err != nil {
				return nil, err
			}

			return &account.DeleteSessionResponse{
				Status:  v,
				Code:    failed.Code,
				Message: failed.Message,
			}, nil
		default:
			return &account.DeleteSessionResponse{
				Status:  "undefined",
				Message: "undefined status",
			}, nil
		}
	case int:
		failed := &model.DeleteFailedResponse{}
		if err := json.Unmarshal(base.Data, &failed); err != nil {
			return nil, err
		}

		return &account.DeleteSessionResponse{
			Status:  strconv.Itoa(v),
			Code:    failed.Code,
			Message: failed.Message,
		}, nil
	default:
		return &account.DeleteSessionResponse{
			Status:  "undefined",
			Message: "undefined status type",
		}, nil
	}
}
