// Package v1 provides migration for mongo repository
package v1

import (
	"context"

	"gitlab.mashroom.com/mashroom/backend/account/internal/model"
	"gitlab.mashroom.com/mashroom/backend/account/internal/util"
	"go.mongodb.org/mongo-driver/bson"
	"go.mongodb.org/mongo-driver/mongo"
)

// Up applies migration
func Up(ctx context.Context, db *mongo.Database, migrationID string) (int, error) {
	accs := db.Collection("accounts")

	cur, err := accs.Find(ctx, bson.M{})
	if err == mongo.ErrNoDocuments {
		return -1, nil
	}

	if err != nil {
		return -1, err
	}

	var acc model.Account

	for cur.Next(ctx) {
		err = cur.Decode(&acc)
		if err == mongo.ErrNoDocuments {
			return -1, nil
		}

		if err != nil {
			return -1, err
		}

		acc.Contact.PhonePrimary = util.NormalizePhoneNumber(acc.Contact.PhonePrimary)
		for _, a := range acc.Contact.PhonesSecondary {
			a.Number = util.NormalizePhoneNumber(a.Number)
		}

		_, err = accs.ReplaceOne(ctx, bson.M{"_id": acc.ID}, acc)
		if err != nil {
			return -1, err
		}
	}

	return -1, nil
}
