package mongo

import (
	"context"
	"errors"

	"gitlab.mashroom.com/mashroom/backend/account/internal/model"
	"go.mongodb.org/mongo-driver/bson"
	"go.mongodb.org/mongo-driver/mongo"
	"go.mongodb.org/mongo-driver/mongo/options"
)

func (repo *repositoryImpl) WistiaVideoSave(ctx context.Context, video *model.WistiaVideo) (err error) {
	_, err = repo.collectionWistia.ReplaceOne(
		ctx,
		bson.M{"_id": video.ID},
		video,
		options.Replace().SetUpsert(true),
	)

	return
}

func (repo *repositoryImpl) WistiaVideoDelete(ctx context.Context, ids []int32, projectID int32) (err error) {
	_, err = repo.collectionWistia.DeleteMany(ctx, bson.M{"_id": bson.M{"$in": ids}, "project.id": projectID})

	return
}

func (repo *repositoryImpl) WistiaVideoListByProjectID(
	ctx context.Context,
	projectID int32,
) (videos []*model.WistiaVideo, err error) {
	filter := bson.M{
		"status": "ready",
	}

	if projectID != 0 {
		filter["project.id"] = projectID
	}

	cur, err := repo.collectionWistia.Find(ctx, filter)
	if err != nil {
		if errors.Is(err, mongo.ErrNoDocuments) {
			return nil, nil
		}

		return
	}

	err = cur.All(ctx, &videos)
	if err != nil {
		if errors.Is(err, mongo.ErrNoDocuments) {
			return nil, nil
		}

		return
	}

	return
}
