// Package model provides model abstraction for account service
package model

import (
	"encoding/json"
	"time"

	"go.mongodb.org/mongo-driver/bson/primitive"
)

// Verification model
type Verification struct {
	Timestamp  time.Time `json:"timestamp"`
	VendorData string    `json:"vendorData"`
	Callback   string    `json:"callback"`
}

// Veriff model
type Veriff struct {
	Verify Verification `json:"verification"`
}

// VerificationResponse model
type VerificationResponse struct {
	ID           string `json:"id"`
	URL          string `json:"url"`
	VendorData   string `json:"vendorData"`
	Host         string `json:"host"`
	Status       string `json:"status"`
	SessionToken string `json:"sessionToken"`
}

// SessionResponse model
type SessionResponse struct {
	Status               string               `json:"status"`
	VerificationResponse VerificationResponse `json:"verification"`
}

// VeriffUpdateResponse model
type VeriffUpdateResponse struct {
	Status               string               `json:"status"`
	VerificationResponse VerificationResponse `json:"verification"`
}

// SessionUpdate model
type SessionUpdate struct {
	Timestamp time.Time `json:"timestamp"`
	Status    string    `json:"status"`
}

// SessionUpdateRequest model
type SessionUpdateRequest struct {
	SessionUpdate SessionUpdate `json:"verification"`
}

// DeleteSucceedResponse model
type DeleteSucceedResponse struct {
	Verification struct {
		ID string `json:"id"`
	} `json:"verification"`
}

// DeleteFailedResponse model
type DeleteFailedResponse struct {
	Code    string `json:"code"`
	Message string `json:"message"`
}

// DeleteBaseResponse model
type DeleteBaseResponse struct {
	Status interface{} `json:"status"`
	Data   json.RawMessage
}

// DecisionResponse contain verification events data
type DecisionResponse struct {
	Status       string `json:"status"`
	Verification struct {
		Comments       []interface{} `json:"comments"`
		DecisionTime   time.Time     `json:"decisionTime"`
		AcceptanceTime time.Time     `json:"acceptanceTime"`
		Person         struct {
			Gender    interface{} `json:"gender"`
			IDNumber  interface{} `json:"idNumber"`
			Addresses []struct {
				ParsedAddress struct {
					City        interface{} `json:"city"`
					Unit        interface{} `json:"unit"`
					State       string      `json:"state"`
					Street      string      `json:"street"`
					Country     string      `json:"country"`
					Postcode    string      `json:"postcode"`
					HouseNumber string      `json:"houseNumber"`
				} `json:"parsedAddress"`
				FullAddress string `json:"fullAddress"`
			} `json:"addresses"`
			Citizenship      interface{} `json:"citizenship"`
			Nationality      interface{} `json:"nationality"`
			PepSanctionMatch interface{} `json:"pepSanctionMatch"`
			FirstName        string      `json:"firstName"`
			DateOfBirth      string      `json:"dateOfBirth"`
			YearOfBirth      string      `json:"yearOfBirth"`
			PlaceOfBirth     string      `json:"placeOfBirth"`
			LastName         string      `json:"lastName"`
		} `json:"person"`
		Document struct {
			ValidFrom    interface{} `json:"validFrom"`
			Type         string      `json:"type"`
			Number       string      `json:"number"`
			Country      string      `json:"country"`
			ValidUntil   string      `json:"validUntil"`
			PlaceOfIssue string      `json:"placeOfIssue"`
			FirstIssue   string      `json:"firstIssue"`
			IssueNumber  string      `json:"issueNumber"`
			IssuedBy     string      `json:"issuedBy"`
		} `json:"document"`
		AdditionalVerifiedData struct {
			DriversLicenseCategoryFrom struct {
				B string `json:"B"`
			} `json:"driversLicenseCategoryFrom"`
			DriversLicenseCategoryUntil struct {
				B string `json:"B"`
			} `json:"driversLicenseCategoryUntil"`
			DriversLicenseCategory struct {
				B bool `json:"B"`
			} `json:"driversLicenseCategory"`
		} `json:"additionalVerifiedData"`
		RiskLabels []struct {
			SessionIds []string `json:"sessionIds"`
			Label      string   `json:"label"`
			Category   string   `json:"category"`
		} `json:"riskLabels"`
		ID         string `json:"id"`
		Reason     string `json:"reason"`
		Status     string `json:"status"`
		VendorData string `json:"vendorData"`
		Code       int32  `json:"code"`
		// Code       int  `json:"code"`
		ReasonCode int32 `json:"reasonCode"`
		// ReasonCode int  `json:"reasonCode"`
	} `json:"verification"`
	TechnicalData struct {
		IP string `json:"ip"`
	} `json:"technicalData"`
}

// EventResponse contain verification events data
type EventResponse struct {
	ID         string `json:"id"`
	AttemptID  string `json:"attemptId"`
	Feature    string `json:"feature"`
	Code       int32  `json:"code"`
	Action     string `json:"action"`
	VendorData string `json:"vendorData"`
}

// VeriffSession model
type VeriffSession struct {
	Documents  []string           `bson:"documents,omitempty"`
	CreatedAt  time.Time          `bson:"created_at,omitempty"`
	UpdatedAt  time.Time          `bson:"updated_at,omitempty"`
	FirstName  string             `bson:"first_name,omitempty"`
	LastName   string             `bson:"last_name,omitempty"`
	AccountID  string             `bson:"account_id,omitempty"`
	AdminID    string             `bson:"admin_id,omitempty"`
	Status     string             `bson:"status"`
	SessionID  string             `bson:"session_id"`
	Reason     string             `bson:"reason"`
	URL        string             `bson:"url,omitempty"`
	VendorData string             `bson:"vendor_data,omitempty"`
	Notes      string             `bson:"notes,omitempty"`
	Code       int32              `bson:"code"`
	ReasonCode int32              `bson:"reason_code"`
	ID         primitive.ObjectID `bson:"_id,omitempty"`
	IsAdmin    bool               `bson:"admin,omitempty"`
}
