package test

import (
	"errors"
	"time"

	account "gitlab.mashroom.com/mashroom/backend/account/api"
	"gitlab.mashroom.com/mashroom/backend/account/internal/model"
	"gitlab.mashroom.com/mashroom/backend/common/generic/mockmatcher"
)

func (s *serviceSuite) TestAccountAddConfirmation_ok() {
	id := "000000000000000000000001"

	s.repo.EXPECT().AccountUpdateConfirmation(
		s.testCtx,
		id,
		mockmatcher.Fields(&model.AccountConfirmation{
			Text:      "abc",
			CreatedAt: time.Now(),
			Confirm:   true,
		}, "CreatedAt"),
	).Return(nil)

	var resp, err = s.srv.AddConfirmation(s.testCtx, &account.ConfirmationRequest{
		User:    id,
		Text:    "abc",
		Confirm: true,
	})

	s.Require().NoError(err)

	s.Require().NotNil(resp)
}

func (s *serviceSuite) TestAccountAddConfirmation_error() {
	id := "000000000000000000000001"

	s.repo.EXPECT().AccountUpdateConfirmation(
		s.testCtx,
		id,
		mockmatcher.Fields(&model.AccountConfirmation{
			Text:      "abc",
			CreatedAt: time.Now(),
			Confirm:   true,
		}, "CreatedAt"),
	).Return(errors.New("someerr"))

	var resp, err = s.srv.AddConfirmation(s.testCtx, &account.ConfirmationRequest{
		User:    id,
		Text:    "abc",
		Confirm: true,
	})

	s.Require().Error(err)

	s.Require().Nil(resp)
}
