package test

import (
	account "gitlab.mashroom.com/mashroom/backend/account/api"
	"gitlab.mashroom.com/mashroom/backend/account/internal/model"
	messaging "gitlab.mashroom.com/mashroom/backend/messaging/api"
	notification "gitlab.mashroom.com/mashroom/backend/notification/api"
)

func (s *serviceSuite) TestAccountChangeBankDetails_ok() {
	id := "000000000000000000000001"

	s.repo.EXPECT().AccountGetByID(s.testCtx, id).Return(&model.Account{
		ID: id,
	}, nil)

	s.repo.EXPECT().AccountUpdate(s.testCtx, &model.Account{
		ID: id,
		BankDetails: model.AccountBankDetails{
			Society:       "111",
			SortCode:      "222",
			AccountNumber: "333",
			AccountName:   "444",
		},
	})

	s.notification.EXPECT().SendNotification(s.testCtx, &notification.SendNotificationRequest{
		Entity: notification.Entity_ENTITY_USER_BANKDETAILS,
		Action: notification.Action_ACTION_UPDATE,
		Targets: []*notification.Target{
			{
				User: id,
				Role: notification.Role_ROLE_AUTHOR,
			},
		},
		Embeds: []*notification.EventEmbed{
			{
				EmbedType:  messaging.EmbedType_EMBED_TYPE_USER,
				EmbedValue: id,
			},
		},
	})

	resp, err := s.srv.ChangeBankDetails(s.testCtx, &account.ChangeBankDetailsRequest{
		BankDetails: &account.AccountBankDetails{
			Society:       "111",
			SortCode:      "222",
			AccountNumber: "333",
			AccountName:   "444",
		},
		User: id,
	})

	s.Require().NoError(err)

	s.Require().NotNil(resp)
}

func (s *serviceSuite) TestAccountChangeBankDetails_error() {
	id := "000000000000000000000001"

	resp, err := s.srv.ChangeBankDetails(s.testCtx, &account.ChangeBankDetailsRequest{
		BankDetails: &account.AccountBankDetails{
			Society:       "",
			SortCode:      "",
			AccountNumber: "",
			AccountName:   "",
		},
		User: id,
	})

	s.Require().NoError(err)

	s.Require().Len(resp.GetErrors(), 1)
}
