package test

import (
	"errors"

	account "gitlab.mashroom.com/mashroom/backend/account/api"
	"gitlab.mashroom.com/mashroom/backend/account/internal/model"
)

func (s *serviceSuite) TestAccountDeleteDocument_ok_user() {
	id := "000000000000000000000001"

	s.repo.EXPECT().AccountGetByID(s.testCtx, id).Return(&model.Account{
		ID: id,
		Details: model.AccountDetails{
			Avatar: "111",
		},
	}, nil)

	s.repo.EXPECT().AccountUpdate(s.testCtx, &model.Account{
		ID: id,
		Details: model.AccountDetails{
			Avatar: "",
		},
	})

	resp, err := s.srv.DeleteDocument(s.testCtx, &account.DeleteDocumentRequest{
		Id:   "111",
		User: id,
	})

	s.Require().NoError(err)

	s.Require().NotNil(resp)
}

func (s *serviceSuite) TestAccountDeleteDocument_ok_file() {
	id := "000000000000000000000001"

	s.repo.EXPECT().AccountGetByID(s.testCtx, id).Return(nil, errors.New("not found"))

	s.repo.EXPECT().AccountGetByAvatar(s.testCtx, "111").Return(&model.Account{
		ID: id,
		Details: model.AccountDetails{
			Avatar: "111",
		},
	}, nil)

	s.repo.EXPECT().AccountUpdate(s.testCtx, &model.Account{
		ID: id,
		Details: model.AccountDetails{
			Avatar: "",
		},
	})

	resp, err := s.srv.DeleteDocument(s.testCtx, &account.DeleteDocumentRequest{
		Id:        "111",
		User:      id,
		AdminSite: true,
	})

	s.Require().NoError(err)

	s.Require().NotNil(resp)
}

func (s *serviceSuite) TestAccountDeleteDocument_error() {
	id := "000000000000000000000001"

	s.repo.EXPECT().AccountGetByID(s.testCtx, id).Return(nil, errors.New("not found"))

	resp, err := s.srv.DeleteDocument(s.testCtx, &account.DeleteDocumentRequest{
		Id:   "111",
		User: id,
	})

	s.Require().Error(err)

	s.Require().Nil(resp)
}

func (s *serviceSuite) TestAccountDeleteDocument_error_mismatch() {
	id := "000000000000000000000001"

	s.repo.EXPECT().AccountGetByID(s.testCtx, id).Return(&model.Account{
		ID: id,
		Details: model.AccountDetails{
			Avatar: "222",
		},
	}, nil)

	resp, err := s.srv.DeleteDocument(s.testCtx, &account.DeleteDocumentRequest{
		Id:   "111",
		User: id,
	})

	s.Require().Error(err)

	s.Require().Nil(resp)
}
