package test

import (
	"errors"

	account "gitlab.mashroom.com/mashroom/backend/account/api"
	"gitlab.mashroom.com/mashroom/backend/account/internal/model"
	"gitlab.mashroom.com/mashroom/backend/common/api/generic/query"
	"gitlab.mashroom.com/mashroom/backend/common/generic/mockmatcher"
	document "gitlab.mashroom.com/mashroom/backend/document/api"
	mockdocument "gitlab.mashroom.com/mashroom/backend/document/api/mock"
)

func (s *serviceSuite) TestAccountDownloadUserCsv_ok() {
	id := "000000000000000000000001"

	params := &query.QueryParams{
		Filter: []*query.QueryParamsFilter{
			{
				Fields:   []string{"aaa"},
				Value:    []string{"bbb"},
				Operator: query.QueryFilterOperator_EQUALS,
			},
		},
	}

	s.repo.EXPECT().AccountListByFilter(
		s.testCtx,
		&query.QueryParams{
			Filter: []*query.QueryParamsFilter{
				{
					Fields:   []string{"aaa"},
					Value:    []string{"bbb"},
					Operator: query.QueryFilterOperator_EQUALS,
				},
				{
					Fields:   []string{"admin"},
					Value:    []string{"false"},
					Operator: query.QueryFilterOperator_EQUALS,
				},
			},
		},
	).Return(
		[]*model.Account{
			{
				ID: id,
				Details: model.AccountDetails{
					FirstName: "aaa",
					LastName:  "bbb",
				},
				Contact: model.AccountContact{
					EmailPrimary: "ccc",
				},
			},
		},
		int64(1),
		nil,
	)

	upl := mockdocument.NewMockDocumentService_FileUploadClient(s.ctrl)

	s.document.EXPECT().FileUpload(s.testCtx).Return(upl, nil)

	upl.EXPECT().Send(mockmatcher.Fields(&document.FileEvent{
		Init: &document.FileInit{
			File: nil,
			Attribute: &document.FileAttribute{
				Data: map[string]string{
					document.FileAttributeGenerated.String(): "true",
				},
			},
		},
	}, "Init.File"))

	upl.EXPECT().Send(mockmatcher.Fields(&document.FileEvent{
		Init: nil,
		Data: nil,
	}, "Data")).MinTimes(1)

	upl.EXPECT().CloseAndRecv()

	var resp, err = s.srv.DownloadUsersCsv(s.testCtx, &account.DownloadUsersCsvRequest{
		Params: &account.DownloadUsersCsvRequest_ParamsValue{
			ParamsValue: params,
		},
		Admin: false,
	})

	s.Require().NoError(err)

	s.Require().NotNil(resp)
}

func (s *serviceSuite) TestAccountDownloadUserCsv_error() {
	params := &query.QueryParams{
		Filter: []*query.QueryParamsFilter{
			{
				Fields:   []string{"aaa"},
				Value:    []string{"bbb"},
				Operator: query.QueryFilterOperator_EQUALS,
			},
		},
	}

	s.repo.EXPECT().AccountListByFilter(
		s.testCtx,
		&query.QueryParams{
			Filter: []*query.QueryParamsFilter{
				{
					Fields:   []string{"aaa"},
					Value:    []string{"bbb"},
					Operator: query.QueryFilterOperator_EQUALS,
				},
				{
					Fields:   []string{"admin"},
					Value:    []string{"false"},
					Operator: query.QueryFilterOperator_EQUALS,
				},
			},
		},
	).Return(
		nil,
		int64(0),
		errors.New("someerr"),
	)

	var resp, err = s.srv.DownloadUsersCsv(s.testCtx, &account.DownloadUsersCsvRequest{
		Params: &account.DownloadUsersCsvRequest_ParamsValue{
			ParamsValue: params,
		},
		Admin: false,
	})

	s.Require().Error(err)

	s.Require().Nil(resp)
}
