package test

import (
	"context"
	"errors"

	account "gitlab.mashroom.com/mashroom/backend/account/api"
	"gitlab.mashroom.com/mashroom/backend/account/internal/model"
	messaging "gitlab.mashroom.com/mashroom/backend/messaging/api"
	notification "gitlab.mashroom.com/mashroom/backend/notification/api"
	"google.golang.org/grpc"
)

func (s *serviceSuite) TestAccountFavorite_ok() {
	id := "000000000000000000000001"

	m := &model.Account{
		ID: id,
	}

	s.repo.EXPECT().AccountGetByID(s.testCtx, id).Return(m, nil)

	s.notification.EXPECT().SendNotification(s.testCtx, &notification.SendNotificationRequest{
		Entity: notification.Entity_ENTITY_PROPERTY_VIEWING_FAVORITE,
		Action: notification.Action_ACTION_CREATE,
		Targets: []*notification.Target{
			{
				User: id,
				Role: notification.Role_ROLE_TENANT,
			},
		},
		Embeds: []*notification.EventEmbed{
			{
				EmbedType:  messaging.EmbedType_EMBED_TYPE_PROPERTY,
				EmbedValue: "123",
			},
		},
	}).Do(func(ctx context.Context, r *notification.SendNotificationRequest, opts ...grpc.CallOption) {
		m.Favorites.Properties = append(m.Favorites.Properties, "123")
	})

	s.repo.EXPECT().AccountUpdate(s.testCtx, m)

	resp, err := s.srv.Favorite(s.testCtx, &account.FavoriteRequest{
		User:  id,
		Type:  account.AccountFavoriteType_ACCOUNT_FAVORITE_PROPERTY,
		Value: "123",
	})

	s.Require().NoError(err)

	s.Require().NotNil(resp)
}

func (s *serviceSuite) TestAccountFavorite_error() {
	id := "000000000000000000000001"

	s.repo.EXPECT().AccountGetByID(s.testCtx, id).Return(nil, errors.New("someerr"))

	resp, err := s.srv.Favorite(s.testCtx, &account.FavoriteRequest{
		User:  id,
		Type:  account.AccountFavoriteType_ACCOUNT_FAVORITE_PROPERTY,
		Value: "123",
	})

	s.Require().Error(err)

	s.Require().Nil(resp)
}
