package test

import (
	"errors"

	account "gitlab.mashroom.com/mashroom/backend/account/api"
	"gitlab.mashroom.com/mashroom/backend/account/internal/model"
	"gitlab.mashroom.com/mashroom/backend/common/api/generic/query"
)

func (s *serviceSuite) TestAccountListFilter_ok() {
	id := "000000000000000000000001"

	params := &query.QueryParams{
		Filter: []*query.QueryParamsFilter{
			{
				Fields:   []string{"aaa"},
				Value:    []string{"bbb"},
				Operator: query.QueryFilterOperator_EQUALS,
			},
		},
	}

	s.repo.EXPECT().AccountListByFilter(s.testCtx, params).Return(
		[]*model.Account{
			{
				ID: id,
			},
		},
		int64(1),
		nil,
	)

	resp, err := s.srv.ListFilter(s.testCtx, &account.AccountListFilterRequest{
		Params: &account.AccountListFilterRequest_ParamsValue{
			ParamsValue: params,
		},
		Admin: false,
	})

	s.Require().NoError(err)

	s.Require().NotNil(resp)
}

func (s *serviceSuite) TestAccountListFilter_error() {
	params := &query.QueryParams{
		Filter: []*query.QueryParamsFilter{
			{
				Fields:   []string{"aaa"},
				Value:    []string{"bbb"},
				Operator: query.QueryFilterOperator_EQUALS,
			},
		},
	}

	s.repo.EXPECT().AccountListByFilter(s.testCtx, params).Return(
		nil,
		int64(0),
		errors.New("someerr"),
	)

	resp, err := s.srv.ListFilter(s.testCtx, &account.AccountListFilterRequest{
		Params: &account.AccountListFilterRequest_ParamsValue{
			ParamsValue: params,
		},
		Admin: false,
	})

	s.Require().Error(err)

	s.Require().Nil(resp)
}
