package test

import (
	"errors"

	account "gitlab.mashroom.com/mashroom/backend/account/api"
	"gitlab.mashroom.com/mashroom/backend/account/internal/model"
)

func (s *serviceSuite) TestAccountResourceUpdate_ok() {
	id := "000000000000000000000001"

	s.repo.EXPECT().AccountGetByID(s.testCtx, id).Return(&model.Account{
		ID: id,
		Resources: model.AccountResources{
			OwnedProperties: []string{"bbb"},
			ViewingRequests: []string{"ddd"},
		},
	}, nil)

	s.repo.EXPECT().AccountUpdate(s.testCtx, &model.Account{
		ID: id,
		Resources: model.AccountResources{
			OwnedProperties: []string{"aaa"},
			ViewingRequests: []string{"ccc"},
		},
	})

	resp, err := s.srv.ServiceResourcesUpdate(s.testCtx, &account.ServiceResourcesUpdateRequest{
		Id: id,
		OwnedProperties: &account.ServiceResourceUpdate{
			Added:   []string{"aaa"},
			Removed: []string{"bbb"},
		},
		ViewingRequests: &account.ServiceResourceUpdate{
			Added:   []string{"ccc"},
			Removed: []string{"ddd"},
		},
	})

	s.Require().NoError(err)

	s.Require().NotNil(resp)
}

func (s *serviceSuite) TestAccountResourceUpdate_error() {
	id := "000000000000000000000001"

	s.repo.EXPECT().AccountGetByID(s.testCtx, id).Return(nil, errors.New("someerr"))

	resp, err := s.srv.ServiceResourcesUpdate(s.testCtx, &account.ServiceResourcesUpdateRequest{
		Id: id,
		OwnedProperties: &account.ServiceResourceUpdate{
			Added:   []string{"aaa"},
			Removed: []string{"bbb"},
		},
		ViewingRequests: &account.ServiceResourceUpdate{
			Added:   []string{"ccc"},
			Removed: []string{"ddd"},
		},
	})

	s.Require().Error(err)

	s.Require().Nil(resp)
}
