package test

import (
	"errors"

	"gitlab.mashroom.com/mashroom/backend/common/api/generic/query"

	"gitlab.mashroom.com/mashroom/backend/account/internal/model"

	account "gitlab.mashroom.com/mashroom/backend/account/api"
)

func (s *serviceSuite) TestAccountServiceList_ok() {
	id := "000000000000000000000001"

	s.repo.EXPECT().AccountListByFilter(s.testCtx, &query.QueryParams{
		Pagination: &query.QueryParamsPagination{
			Page:    0,
			PerPage: 1000,
		},
		Sort: nil,
		Filter: []*query.QueryParamsFilter{
			{
				Fields:   []string{"admin"},
				Value:    []string{"false"},
				Operator: query.QueryFilterOperator_EQUALS,
			},
		},
	}).Return(
		[]*model.Account{
			{
				ID: id,
			},
		},
		int64(1),
		nil,
	)

	resp, err := s.srv.ServiceList(s.testCtx, &account.ServiceListRequest{
		Admin: false,
	})

	s.Require().NoError(err)

	s.Require().NotNil(resp)
}

func (s *serviceSuite) TestAccountServiceList_error() {
	s.repo.EXPECT().AccountListByFilter(s.testCtx, &query.QueryParams{
		Pagination: &query.QueryParamsPagination{
			Page:    0,
			PerPage: 1000,
		},
		Sort: nil,
		Filter: []*query.QueryParamsFilter{
			{
				Fields:   []string{"admin"},
				Value:    []string{"false"},
				Operator: query.QueryFilterOperator_EQUALS,
			},
		},
	}).Return(
		nil,
		int64(0),
		errors.New("someerr"),
	)

	resp, err := s.srv.ServiceList(s.testCtx, &account.ServiceListRequest{
		Admin: false,
	})

	s.Require().Error(err)

	s.Require().Nil(resp)
}
