package test

import (
	"errors"

	account "gitlab.mashroom.com/mashroom/backend/account/api"
	"gitlab.mashroom.com/mashroom/backend/account/internal/model"
)

func (s *serviceSuite) TestAccountUnfavorite_ok() {
	id := "000000000000000000000001"

	m := &model.Account{
		ID: id,
		Favorites: model.AccountFavorites{
			Properties: []string{"123"},
		},
	}

	s.repo.EXPECT().AccountGetByID(s.testCtx, id).Return(m, nil)

	s.repo.EXPECT().AccountUpdate(s.testCtx, &model.Account{
		ID: id,
		Favorites: model.AccountFavorites{
			Properties: []string{},
		},
	})

	resp, err := s.srv.Unfavorite(s.testCtx, &account.UnfavoriteRequest{
		User:  id,
		Type:  account.AccountFavoriteType_ACCOUNT_FAVORITE_PROPERTY,
		Value: "123",
	})

	s.Require().NoError(err)

	s.Require().NotNil(resp)
}

func (s *serviceSuite) TestAccountUnfavorite_error() {
	id := "000000000000000000000001"

	s.repo.EXPECT().AccountGetByID(s.testCtx, id).Return(nil, errors.New("someerr"))

	resp, err := s.srv.Unfavorite(s.testCtx, &account.UnfavoriteRequest{
		User:  id,
		Type:  account.AccountFavoriteType_ACCOUNT_FAVORITE_PROPERTY,
		Value: "123",
	})

	s.Require().Error(err)

	s.Require().Nil(resp)
}
