package test

import (
	"github.com/camunda-cloud/zeebe/clients/go/pkg/entities"
	"github.com/camunda-cloud/zeebe/clients/go/pkg/pb"
	"github.com/camunda-cloud/zeebe/clients/go/pkg/worker"
	"github.com/golang/mock/gomock"
	"gitlab.mashroom.com/mashroom/backend/common/generic/dbfilter"
	"gitlab.mashroom.com/mashroom/backend/common/generic/mockmatcher"
	mockzeebe "gitlab.mashroom.com/mashroom/backend/zeebe/api/mock"
)

func (s *serviceSuite) TestBpmAccountCount_ok() {
	var handler worker.JobHandler

	s.zbcclient.EXPECT().NewJobWorker().Return(mockzeebe.JobWorkerBuilderMock(
		s.ctrl,
		"account-service",
		mockmatcher.Func("capture handler", func(v worker.JobHandler) bool {
			handler = v

			return true
		}),
	))

	_, err := s.srv.RegisterProcessHandlers()

	s.Require().NoError(err)

	s.repo.EXPECT().AccountCount(gomock.Any(), dbfilter.Eq("contact.email_primary", "foo@bar.baz")).Return(
		int64(1),
		nil,
	)

	s.zbcclient.EXPECT().NewCompleteJobCommand().Return(mockzeebe.JobCompleteMock(
		s.ctrl,
		int64(123),
		mockmatcher.Func("complete capture", func(value string) bool {
			return value == `{"count":1}`
		}),
		&pb.CompleteJobResponse{},
	))

	handler(s.zbcclient, entities.Job{
		ActivatedJob: &pb.ActivatedJob{
			Key:           123,
			CustomHeaders: `{"op": "account-count"}`,
			Variables:     `{"contact": {"email_primary": "foo@bar.baz"}}`,
		},
	})
}

func (s *serviceSuite) TestBpmAccountCount_ok_fields() {
	var handler worker.JobHandler

	s.zbcclient.EXPECT().NewJobWorker().Return(mockzeebe.JobWorkerBuilderMock(
		s.ctrl,
		"account-service",
		mockmatcher.Func("capture handler", func(v worker.JobHandler) bool {
			handler = v

			return true
		}),
	))

	_, err := s.srv.RegisterProcessHandlers()

	s.Require().NoError(err)

	s.repo.EXPECT().AccountCount(
		gomock.Any(),
		dbfilter.Eq("contact.email_primary", "foo@bar.baz"),
		dbfilter.Eq("contact.phone_primary", "111"),
		dbfilter.Match("details.first_name", dbfilter.Pattern("aaa")),
		dbfilter.Match("details.last_name", dbfilter.Pattern("bbb")),
	).Return(
		int64(1),
		nil,
	)

	s.zbcclient.EXPECT().NewCompleteJobCommand().Return(mockzeebe.JobCompleteMock(
		s.ctrl,
		int64(123),
		mockmatcher.Func("complete capture", func(value string) bool {
			return value == `{"count":1}`
		}),
		&pb.CompleteJobResponse{},
	))

	handler(s.zbcclient, entities.Job{
		ActivatedJob: &pb.ActivatedJob{
			Key:           123,
			CustomHeaders: `{"op": "account-count"}`,
			Variables: `
{
  "contact": {"email_primary": "foo@bar.baz", "phone_primary": "111"},
  "details": {"first_name": "aaa", "last_name": "bbb"}
}
`,
		},
	})
}
